summaryrefslogtreecommitdiffstats
path: root/kate/interfaces/katecmd.h
diff options
context:
space:
mode:
Diffstat (limited to 'kate/interfaces/katecmd.h')
-rw-r--r--kate/interfaces/katecmd.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kate/interfaces/katecmd.h b/kate/interfaces/katecmd.h
index b01f6dafb..262781aa3 100644
--- a/kate/interfaces/katecmd.h
+++ b/kate/interfaces/katecmd.h
@@ -53,12 +53,12 @@ class KATEPARTINTERFACES_EXPORT KateCmd
};
/**
* A KCompletion object that completes last ?unquoted? word in the string
* passed. Dont mistake "shell" for anything related to quoting, this
* simply mimics shell tab completion by completing the last word in the
* provided text.
*/
-class KATEPARTINTERFACES_EXPORT KateCmdShellCompletion : public KCompletion
+class KATEPARTINTERFACES_EXPORT KateCmdShellCompletion : public TDECompletion
{
public:
KateCmdShellCompletion();
@@ -72,10 +72,10 @@ class KATEPARTINTERFACES_EXPORT KateCmdShellCompletion : public KCompletion
TQString makeCompletion(const TQString &text);
protected:
// Called by KCompletion
void postProcessMatch( TQString *match ) const;
void postProcessMatches( TQStringList *matches ) const;
- void postProcessMatches( KCompletionMatches *matches ) const;
+ void postProcessMatches( TDECompletionMatches *matches ) const;
private:
/**
@@ -53,12 +53,12 @@ class KATEPARTINTERFACES_EXPORT KateCmd
};
/**
- * A KCompletion object that completes last ?unquoted? word in the string
+ * A TDECompletion object that completes last ?unquoted? word in the string
* passed. Dont mistake "shell" for anything related to quoting, this
* simply mimics shell tab completion by completing the last word in the
@@ -72,10 +72,10 @@ class KATEPARTINTERFACES_EXPORT KateCmdShellCompletion : public KCompletion
TQString makeCompletion(const TQString &text);
protected:
- // Called by KCompletion
+ // Called by TDECompletion
void postProcessMatch( TQString *match ) const;
void postProcessMatches( TQStringList *matches ) const;